summaryrefslogtreecommitdiff
path: root/nuttx/arch/arm/src/armv7-m/vfork.S
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2013-01-07 21:41:20 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2013-01-07 21:41:20 +0000
commit89f3c966e75b483eaeb4af2a85721f9b1d8ed4e2 (patch)
treeb5cbba4326a2edbbb9b1723492e38a408fcb3241 /nuttx/arch/arm/src/armv7-m/vfork.S
parent8514e37561246aee4dfbf569b474663aca368913 (diff)
downloadpx4-nuttx-89f3c966e75b483eaeb4af2a85721f9b1d8ed4e2.tar.gz
px4-nuttx-89f3c966e75b483eaeb4af2a85721f9b1d8ed4e2.tar.bz2
px4-nuttx-89f3c966e75b483eaeb4af2a85721f9b1d8ed4e2.zip
Add ostest vfork test (does not work yet)
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@5488 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/arch/arm/src/armv7-m/vfork.S')
-rw-r--r--nuttx/arch/arm/src/armv7-m/vfork.S10
1 files changed, 5 insertions, 5 deletions
diff --git a/nuttx/arch/arm/src/armv7-m/vfork.S b/nuttx/arch/arm/src/armv7-m/vfork.S
index aceded400..0d9e144cd 100644
--- a/nuttx/arch/arm/src/armv7-m/vfork.S
+++ b/nuttx/arch/arm/src/armv7-m/vfork.S
@@ -52,7 +52,7 @@
.syntax unified
.thumb
.file "vfork.S"
- .globl task_vfork
+ .globl up_vfork
/************************************************************************************
* Public Functions
@@ -68,7 +68,7 @@
* from the function in which vfork() was called, or calls any other function before
* successfully calling _exit() or one of the exec family of functions.
*
* This thin layer implements vfork by simply calling task_vfork() with the vfork()
* context as an argument. The overall sequence is:
*
* 1) User code calls vfork(). vfork() collects context information and
@@ -124,12 +124,12 @@ vfork:
str r0, [sp, #VFORK_SP_OFFSET]
str lr, [sp, #VFORK_LR_OFFSET]
/* Then, call task_vfork(), passing it a pointer to the stack structure */
mov r0, sp
- bl task_vfork
+ bl up_vfork
- /* Release the stack data and return the value returned by task_vfork */
+ /* Release the stack data and return the value returned by up_vfork */
add sp, sp, #VFORK_SIZEOF
bx lr
@@ -68,7 +68,7 @@
* successfully calling _exit() or one of the exec family of functions.
*
- * This thin layer implements vfork by simply calling task_vfork() with the vfork()
+ * This thin layer implements vfork by simply calling up_vfork() with the vfork()
* context as an argument. The overall sequence is:
*
@@ -124,12 +124,12 @@ vfork:
str r0, [sp, #VFORK_SP_OFFSET]
str lr, [sp, #VFORK_LR_OFFSET]
- /* Then, call task_vfork(), passing it a pointer to the stack structure */
+ /* Then, call up_vfork(), passing it a pointer to the stack structure */
mov r0, sp